@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 __author__ = """CloudHeads"""
 __email__ = 'theguys@cloudheads.io'
-__version__ = '0.2.10'
+__version__ = '0.2.11'
 
-import logging
 from concurrent.futures import ThreadPoolExecutor
-from response_handlers import BaseResponseHandler
+
 from logger import BaseLogger
+from response_handlers import BaseResponseHandler
 
 
 class LambdaProcessor:
@@ -20,18 +20,14 @@ class LambdaProcessor:
             logger.on_init(function)
 
     def on_execution(self, event):
-        logging.debug(event)
-
         for logger in self.loggers:
             logger.on_execution(event)
         return self.response_handler.on_execution(event)
 
     def on_response(self, response):
-        logging.debug(response)
         return self.response_handler.on_response(response)
 
     def on_exception(self, ex):
-        logging.exception(ex.message)
         return self.response_handler.on_exception(ex)
 
     def __call__(self, function):
@@ -43,8 +39,6 @@ class LambdaProcessor:
         if hasattr(context, 'get_remaining_time_in_millis'):
             seconds = (context.get_remaining_time_in_millis() / 1000.00) - 1.0
             return seconds
-        else:
-            logging.debug('Add logging on timeout failed. context.get_remaining_time_in_millis() missing?')
 
     def wrapped_function(self, event, context):
         try:
